@@ -7,7 +7,7 @@
  * it under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
  *
- * $Id: Scenario.cpp 1218 2005-11-21 13:26:55Z cs $
+ * $Id: Scenario.cpp 1341 2006-09-30 15:10:11Z cs $
  */
 
 #include "Scenario.h"
@@ -26,6 +26,7 @@ Scenario::Scenario(Project* p, const QString& i, const QString& n,
         projectionMode = pr->projectionMode;
         optimize = pr->optimize;
         strictBookings = pr->strictBookings;
+        minSlackRate = pr->minSlackRate;
     }
     else
     {
@@ -33,6 +34,7 @@ Scenario::Scenario(Project* p, const QString& i, const QString& n,
         projectionMode = false;
         optimize = false;
         strictBookings = false;
+        minSlackRate = 10.0;
     }
 }
 
